@@ -5,8 +5,8 @@ using namespace std;
 
 
 
-vcf::Variant& Results::vcf(
-    vcf::Variant& var, // variant to update
+vcflib::Variant& Results::vcf(
+    vcflib::Variant& var, // variant to update
     BigFloat pHom,
     long double bestComboOddsRatio,
     //long double alleleSamplingProb,
@@ -53,7 +53,7 @@ vcf::Variant& Results::vcf(
 
     // get the required size of the reference sequence
     // strip identical bases from start and/or end of alleles
-    // if bases have been stripped from the beginning, 
+    // if bases have been stripped from the beginning,
 
     // set up VCF record-wide variables
 
@@ -76,6 +76,7 @@ vcf::Variant& Results::vcf(
     if (parameters.calculateMarginals) var.format.push_back("GQ");
     // XXX
     var.format.push_back("DP");
+    var.format.push_back("AD");
     var.format.push_back("RO");
     var.format.push_back("QR");
     var.format.push_back("AO");
@@ -296,7 +297,7 @@ vcf::Variant& Results::vcf(
         long double altReadMismatchRate = (altObsCount == 0 ? 0 : altReadMismatchSum / altObsCount);
         long double altReadSNPRate = (altObsCount == 0 ? 0 : altReadSNPSum / altObsCount);
         long double altReadIndelRate = (altObsCount == 0 ? 0 : altReadIndelSum / altObsCount);
-        
+
         //var.info["XAM"].push_back(convert(altReadMismatchRate));
         //var.info["XAS"].push_back(convert(altReadSNPRate));
         //var.info["XAI"].push_back(convert(altReadIndelRate));
@@ -420,7 +421,7 @@ vcf::Variant& Results::vcf(
     // tally partial observations to get a mean coverage per bp of reference
     int haplotypeLength = refbase.size();
     int basesInObservations = 0;
-    
+
     for (map<string, vector<Allele*> >::iterator g = alleleGroups.begin(); g != alleleGroups.end(); ++g) {
         for (vector<Allele*>::iterator a = g->second.begin(); a != g->second.end(); ++a) {
             basesInObservations += (*a)->alternateSequence.size();
@@ -430,7 +431,7 @@ vcf::Variant& Results::vcf(
     for (map<Allele*, set<Allele*> >::iterator p = partialObservationSupport.begin(); p != partialObservationSupport.end(); ++p) {
         basesInObservations += p->first->alternateSequence.size();
     }
- 
+
     double depthPerBase = (double) basesInObservations / (double) haplotypeLength;
     var.info["DPB"].push_back(convert(depthPerBase));
 
@@ -510,10 +511,15 @@ vcf::Variant& Results::vcf(
             sampleOutput["GT"].push_back(genotype->relativeGenotype(refbase, altAlleles));
 
             if (parameters.calculateMarginals) {
-                sampleOutput["GQ"].push_back(convert(nan2zero(big2phred((BigFloat)1 - big_exp(sampleLikelihoods.front().marginal)))));
+                double val = nan2zero(big2phred((BigFloat)1 - big_exp(sampleLikelihoods.front().marginal)));
+                if (parameters.strictVCF)
+                    sampleOutput["GQ"].push_back(convert(int(round(val))));
+                else
+                    sampleOutput["GQ"].push_back(convert(val));
             }
 
             sampleOutput["DP"].push_back(convert(sample.observationCount()));
+            sampleOutput["AD"].push_back(convert(sample.observationCount(refbase)));
             sampleOutput["RO"].push_back(convert(sample.observationCount(refbase)));
             sampleOutput["QR"].push_back(convert(sample.qualSum(refbase)));
 
@@ -521,6 +527,7 @@ vcf::Variant& Results::vcf(
                 Allele& altAllele = *aa;
                 string altbase = altAllele.base();
                 sampleOutput["AO"].push_back(convert(sample.observationCount(altbase)));
+                sampleOutput["AD"].push_back(convert(sample.observationCount(altbase)));
                 sampleOutput["QA"].push_back(convert(sample.qualSum(altbase)));
             }
 
@@ -630,8 +637,8 @@ vcf::Variant& Results::vcf(
 }
 
 
-vcf::Variant& Results::gvcf(
-    vcf::Variant& var,
+vcflib::Variant& Results::gvcf(
+    vcflib::Variant& var,
     NonCalls& nonCalls,
     AlleleParser* parser) {
 
@@ -652,7 +659,7 @@ vcf::Variant& Results::gvcf(
     assert(numSites > 0);
 
     // set up site call
-    var.ref = parser->currentReferenceBaseString();
+    var.ref = parser->referenceSubstr(startPos, 1);
     var.alt.push_back("<*>");
     var.sequenceName = parser->currentSequenceName;
     var.position = startPos + 1; // output text field is one-based
@@ -664,19 +671,28 @@ vcf::Variant& Results::gvcf(
     var.format.clear();
     var.format.push_back("GQ");
     var.format.push_back("DP");
-    var.format.push_back("MIN");
+    var.format.push_back("MIN_DP");
     var.format.push_back("QR");
     var.format.push_back("QA");
-    
+
     NonCall total = nonCalls.aggregateAll();
+
+    /* This resets min depth to zero if nonCalls is less than numSites. */
+
+    int minDepth = total.minDepth;
+
+    if(numSites != total.nCount){
+        minDepth = 0;
+    }
+
     var.info["DP"].push_back(convert((total.refCount+total.altCount) / numSites));
-    var.info["MIN"].push_back(convert(total.minDepth));
+    var.info["MIN_DP"].push_back(convert(minDepth));
     // The text END field is one-based, inclusive. We proudly conflate this
     // with our zero-based, exclusive endPos.
     var.info["END"].push_back(convert(endPos));
 
     // genotype quality is 1- p(polymorphic)
-    
+
     map<string, NonCall> perSample;
     nonCalls.aggregatePerSample(perSample);
 
@@ -688,8 +704,18 @@ vcf::Variant& Results::gvcf(
         map<string, vector<string> >& sampleOutput = var.samples[sampleName];
         long double qual = nc.reflnQ - nc.altlnQ;
         sampleOutput["GQ"].push_back(convert(ln2phred(qual)));
+
+
+      /* This resets min depth to zero if nonCalls is less than numSites. */
+
+        int minDepth = nc.minDepth;
+
+        if(numSites != nc.nCount){
+            minDepth = 0;
+        }
+
         sampleOutput["DP"].push_back(convert((nc.refCount+nc.altCount) / numSites));
-        sampleOutput["MIN"].push_back(convert(nc.minDepth));
+        sampleOutput["MIN_DP"].push_back(convert(minDepth));
         sampleOutput["QR"].push_back(convert(ln2phred(nc.reflnQ)));
         sampleOutput["QA"].push_back(convert(ln2phred(nc.altlnQ)));
     }
